@@ -15,13 +15,14 @@ class AxisGL(GLDrawable):
     def __init__(self, element=None, *args, **kwargs):
         super().__init__(element, *args, **kwargs)
 
+    def generate_buffers(self) -> None:
+        self._vaos = [glGenVertexArrays(1)]
+        self._vbos = glGenBuffers(2)
+
     def setup_attributes(self) -> None:
         _POSITION = 0
         _COLOR = 1
 
-        # Generate VAO and VBOs (see GLDrawable)
-        self.generate_buffers(2)
-
         # Data
         vertices = np.array([[0.0, 0.0, 0.0], [1.0, 0.0, 0.0],
                              [0.0, 0.0, 0.0], [0.0, 1.0, 0.0],
