@@ -5,6 +5,7 @@
 #  Distributed under the MIT License.
 #  See LICENSE for more info.
 
+import numpy as np
 from OpenGL.GL import *
 
 
@@ -21,6 +22,11 @@ class GLDrawable:
         self._is_visible = kwargs.pop('visible', True)
         self._is_boostable = kwargs.pop('turbo', False)
 
+        # If a drawable is too far from zero, it tends to wobble.
+        # This idea allows the drawable to be rendered near zero,
+        # without altering the original vertices
+        self._rendering_offset = kwargs.pop('rendering_offset', np.zeros(3))
+
     # Note: The following "hacks" are shortened versions of Delegator Pattern.
     # They're convenient, but optional.
     #
@@ -119,6 +125,17 @@ class GLDrawable:
         self._is_boostable = status
         self.notify()
 
+    """
+    Render adjustments
+    """
+    @property
+    def rendering_offset(self) -> np.ndarray:
+        return self._rendering_offset
+
+    @rendering_offset.setter
+    def rendering_offset(self, value: iter) -> None:
+        self._rendering_offset = np.asarray(value)
+
     """
     Quick GLDrawable API
     """
