@@ -25,7 +25,7 @@ class LineGL(GLDrawable):
         _COLOR = 1
 
         # Data
-        vertices = self.element.vertices.astype(np.float32)
+        vertices = (self.element.vertices + self.rendering_offset).astype(np.float32)
         colors = self.element.rgba.astype(np.float32)
 
         # np.array([[0, 1, 2]], type) has size 3, despite having only 1 list there
