@@ -12,12 +12,27 @@ class FPSCounter:
     def __init__(self, resolution: float = 1.0):
         self.start_time = time.time()
         self.resolution = resolution
+        self.callbacks = []
         self.counter = 0
 
-    def tick(self, callback=lambda *args: None) -> None:
+    def add_callback(self, callback: callable) -> None:
+        self.callbacks.append(callback)
+
+    def pop_callback(self) -> callable:
+        return self.callbacks.pop()
+
+    def clear_callbacks(self) -> None:
+        self.callbacks.clear()
+
+    def notify(self, fps: float) -> None:
+        for callback in self.callbacks:
+            callback(fps)
+
+    def tick(self) -> None:
         self.counter += 1
         if time.time() - self.start_time > self.resolution:
             diff = (time.time() - self.start_time)
-            callback(self.counter / diff if diff else 0.0)
+            self.notify(self.counter / diff if diff else 0.0)
+
             self.counter = 0
             self.start_time = time.time()
