@@ -10,8 +10,8 @@ from OpenGL.GL import *
 
 
 class MeshProgram(ShaderProgram):
-    def __init__(self, viewer):
-        super().__init__(viewer)
+    def __init__(self):
+        super().__init__()
         self.base_name = 'Mesh'
 
     def redraw(self) -> None:
