@@ -103,10 +103,14 @@ class IntegrableViewer(QOpenGLWidget):
         self.current_controller = None
         self.controllers = {}
 
-        # Camera/World/Projection
-        self.camera = QMatrix4x4()
-        self.world = QMatrix4x4()
-        self.proj = QMatrix4x4()
+        # Model/View/Projection matrices (math)
+        self.model_matrix = QMatrix4x4()
+        self.view_matrix = QMatrix4x4()
+        self.proj_matrix = QMatrix4x4()
+
+        # Model/View matrices (rendering offset)
+        self.render_model_matrix = QMatrix4x4()
+        self.render_view_matrix = QMatrix4x4()
 
         # FPS Counter
         self.fps_counter = FPSCounter()
@@ -115,6 +119,7 @@ class IntegrableViewer(QOpenGLWidget):
         self._rotation_center = np.array([0.0, 0.0, 0.0])
         self._rotation_angle = np.array([0.0, 0.0, 0.0])
         self._camera_position = np.array([0.0, 0.0, 200.0])
+        self._rendering_offset = np.array([0.0, 0.0, 0.0])
 
         # Cross-section data
         self.last_cross_origin = np.asarray([0.0, 0.0, 0.0])
@@ -123,6 +128,7 @@ class IntegrableViewer(QOpenGLWidget):
         self.is_phantom_enabled = False
 
         # Extra information
+        self.is_gl_initialized = False
         self.is_animated = False
         self.fov = 45.0
         self.smoothness = 2.0  # Bigger => smoother (but slower) rotations
@@ -167,33 +173,25 @@ class IntegrableViewer(QOpenGLWidget):
         self.pre_collection.initialize()
         self.drawable_collection.initialize()
         self.post_collection.initialize()
+        self.is_gl_initialized = True
 
     def paintGL(self) -> None:
         # Clear screen
         glClear(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT)
 
-        self.world.setToIdentity()
-        self.camera.setToIdentity()
+        # Setup model matrix
+        self.setup_model_matrix(self.model_matrix, self.rotation_angle, self.rotation_center)
+        self.setup_model_matrix(self.render_model_matrix, self.rotation_angle, self.render_rotation_center)
 
-        # Translate by rotation center (world position)
-        self.world.translate(*self.rotation_center)
-
-        # Allow rotation of the world
-        self.world.rotate(self.rotation_angle[0], 1.0, 0.0, 0.0)
-        self.world.rotate(self.rotation_angle[1], 0.0, 1.0, 0.0)
-        self.world.rotate(self.rotation_angle[2], 0.0, 0.0, 1.0)
-
-        # Restore world
-        self.world.translate(*-self.rotation_center)
-
-        # Translate the camera
-        self.camera.translate(*-self.camera_position)
+        # Setup view matrix
+        self.setup_view_matrix(self.view_matrix, self.camera_position)
+        self.setup_view_matrix(self.render_view_matrix, self.render_camera_position)
 
         # Propagate common uniform values (programs lacking the uniform will ignore the command)
         for collection in [self.pre_collection, self.drawable_collection, self.post_collection]:
             # MVP matrices
-            collection.update_uniform('proj_matrix', self.proj)
-            collection.update_uniform('model_view_matrix', self.camera * self.world)
+            collection.update_uniform('proj_matrix', self.proj_matrix)
+            collection.update_uniform('model_view_matrix', self.render_view_matrix * self.render_model_matrix)
 
             # Viewport values (with DPI awareness)
             collection.update_uniform('viewport', *self.viewport)
@@ -212,19 +210,33 @@ class IntegrableViewer(QOpenGLWidget):
         self.fps_counter.tick()
 
     def resizeGL(self, w: float, h: float) -> None:
-        self.proj.setToIdentity()
+        self.proj_matrix.setToIdentity()
 
         if self.current_projection == 'Perspective':
-            self.proj.perspective(self.fov, self.aspect, 1.0, 100000.0)
+            self.proj_matrix.perspective(self.fov, self.aspect, 1.0, 100000.0)
         else:  # if self.current_projection == 'Orthographic':
             z = self.off_center[2] * 0.65
-            self.proj.ortho(-z, z, -z / self.aspect, z / self.aspect, 0.0, 100000.0)
+            self.proj_matrix.ortho(-z, z, -z / self.aspect, z / self.aspect, 0.0, 100000.0)
 
-    def recreate(self) -> None:
-        self.pre_collection.recreate()
-        self.drawable_collection.recreate()
-        self.post_collection.recreate()
-        self.update()
+    @staticmethod
+    def setup_model_matrix(matrix: QMatrix4x4, rotation: np.ndarray, translation: np.ndarray) -> None:
+        matrix.setToIdentity()
+
+        # Translate matrix (translation = rotation_center)
+        matrix.translate(*translation)
+
+        # Rotate matrix
+        matrix.rotate(rotation[0], 1.0, 0.0, 0.0)
+        matrix.rotate(rotation[1], 0.0, 1.0, 0.0)
+        matrix.rotate(rotation[2], 0.0, 0.0, 1.0)
+
+        # Restore matrix
+        matrix.translate(*-translation)
+
+    @staticmethod
+    def setup_view_matrix(matrix: QMatrix4x4, camera: iter) -> None:
+        matrix.setToIdentity()
+        matrix.translate(*-camera)
 
     """
     Properties
@@ -288,6 +300,31 @@ class IntegrableViewer(QOpenGLWidget):
         self._rotation_center = np.asarray(value)
         self.signal_center_translated.emit(value)
 
+    """
+    Rendering offsets
+    """
+    @property
+    def rendering_offset(self) -> np.ndarray:
+        return self._rendering_offset
+
+    @rendering_offset.setter
+    def rendering_offset(self, value: iter) -> None:
+        self._rendering_offset = np.asarray(value)
+
+        for drawable in self.get_all_drawables():
+            drawable.rendering_offset = value
+
+        if self.is_gl_initialized:
+            self.update_all()
+
+    @property
+    def render_camera_position(self) -> np.ndarray:
+        return self.camera_position + self.rendering_offset
+
+    @property
+    def render_rotation_center(self) -> np.ndarray:
+        return self.rotation_center + self.rendering_offset
+
     """
     API for partial camera movements/rotations
     """
@@ -411,6 +448,9 @@ class IntegrableViewer(QOpenGLWidget):
         drawable.add_observer(self)
         collection.add(drawable)
 
+        # Update the new drawable with the current rendering offset
+        drawable.rendering_offset = self.rendering_offset
+
         # Emit success signals
         self.signal_file_modified.emit()
         self.signal_load_success.emit(drawable.id)
@@ -549,7 +589,7 @@ class IntegrableViewer(QOpenGLWidget):
     def update_all(self) -> None:
         self.makeCurrent()
         for _id in self.get_all_ids():
-            self.get_drawable(_id).setup_attributes()
+            self.get_drawable(_id).reload()
         self.recreate()
 
     def clear(self) -> None:
@@ -558,6 +598,12 @@ class IntegrableViewer(QOpenGLWidget):
         self.drawable_collection.clear()
         self.signal_file_modified.emit()
 
+    def recreate(self) -> None:
+        self.pre_collection.recreate()
+        self.drawable_collection.recreate()
+        self.post_collection.recreate()
+        self.update()
+
     """
     Drawable retrieval
     """
@@ -641,6 +687,10 @@ class IntegrableViewer(QOpenGLWidget):
 
         return min_all, max_all
 
+    def fix_wobbling(self) -> None:
+        # Update offset to minimize wobbling
+        self.rendering_offset = -self.rotation_center
+
     """
     Utilities
     """
@@ -671,7 +721,7 @@ class IntegrableViewer(QOpenGLWidget):
         vector = [x, y, -1.0, 1.0]
         temp_matrix = QMatrix4x4(*[e for e in vector for _ in range(4)])
 
-        ray_eye = (self.proj.inverted()[0] * temp_matrix).column(0)
+        ray_eye = (self.proj_matrix.inverted()[0] * temp_matrix).column(0)
         ray_eye = QVector4D(ray_eye.x(), ray_eye.y(), -1.0, 0.0)
 
         # We'd use `ray_eye`, but PySide2
@@ -679,7 +729,7 @@ class IntegrableViewer(QOpenGLWidget):
         vector = [ray_eye.x(), ray_eye.y(), ray_eye.z(), ray_eye.w()]
         temp_matrix = QMatrix4x4(*[e for e in vector for _ in range(4)])
 
-        ray_world = ((self.camera * self.world).inverted()[0] * temp_matrix).column(0).toVector3D()
+        ray_world = ((self.view_matrix * self.model_matrix).inverted()[0] * temp_matrix).column(0).toVector3D()
         ray = ray_world.normalized()
         return np.array([ray.x(), ray.y(), ray.z()])
 
@@ -694,7 +744,7 @@ class IntegrableViewer(QOpenGLWidget):
     def origin_from_click(self, x: float, y: float, z: float) -> np.ndarray:
         # Perspective projection is straightforward
         def perspective_origin() -> np.ndarray:
-            origin = (self.camera * self.world).inverted()[0].column(3).toVector3D()
+            origin = (self.view_matrix * self.model_matrix).inverted()[0].column(3).toVector3D()
             return np.array([origin.x(), origin.y(), origin.z()])
 
         # Orthographic projection needs a bit more of vector arithmetic.
@@ -713,9 +763,9 @@ class IntegrableViewer(QOpenGLWidget):
             offset = self.off_center[2] * ndc * aspect_bias
 
             # Hack to get the origin when the click is not exactly at center of screen.
-            self.camera.translate(*-offset)
+            self.view_matrix.translate(*-offset)
             origin = perspective_origin()
-            self.camera.translate(*offset)
+            self.view_matrix.translate(*offset)
 
             return origin
 
